@@ -34,43 +34,11 @@
 #include <gdk/gdkx.h>
 #include <X11/Xatom.h>
 
+#include "private.h"
+#include "gnome-rr-private.h"
+
 #define DISPLAY(o) ((o)->info->screen->xdisplay)
 
-typedef struct ScreenInfo ScreenInfo;
-
-struct ScreenInfo
-{
-    int			min_width;
-    int			max_width;
-    int			min_height;
-    int			max_height;
-
-    XRRScreenResources *resources;
-    
-    GnomeRROutput **	outputs;
-    GnomeRRCrtc **	crtcs;
-    GnomeRRMode **	modes;
-    
-    GnomeRRScreen *	screen;
-
-    GnomeRRMode **	clone_modes;
-};
-
-struct GnomeRRScreen
-{
-    GdkScreen *			gdk_screen;
-    GdkWindow *			gdk_root;
-    Display *			xdisplay;
-    Screen *			xscreen;
-    Window			xroot;
-    ScreenInfo *		info;
-    
-    int				randr_event_base;
-    
-    GnomeRRScreenChanged	callback;
-    gpointer			data;
-};
-
 struct GnomeRROutput
 {
     ScreenInfo *	info;
@@ -537,6 +505,8 @@ gnome_rr_screen_new (GdkScreen *gdk_screen,
 
     g_return_val_if_fail (error == NULL || *error == NULL, NULL);
     
+    _gnome_desktop_init_i18n ();
+
     if (XRRQueryExtension (dpy, &event_base, &ignore))
     {
 	GnomeRRScreen *screen = g_new0 (GnomeRRScreen, 1);
